Write-code questions
-----------------------
.. selectquestion:: str-ex-hi
   :fromid: str-ex-hiacq, str-ex-hiansw
   :toggle: lock

.. selectquestion:: str-ex-meow
   :fromid: str-ex-meowacq, str-ex-meowansw
   :toggle: lock

.. selectquestion:: str-ex-eggs
   :fromid: str-ex-eggsacq, str-ex-eggsansw
   :toggle: lock

.. selectquestion:: str-ex-count
   :fromid: str-ex-countacq, str-ex-countansw
   :toggle: lock

.. selectquestion:: str-ex-float
   :fromid: str-ex-floatacq, str-ex-floatansw
   :toggle: lock

.. selectquestion:: str-ex-ducks
   :fromid: str-ex-ducksacq, str-ex-ducksansw
   :toggle: lock

.. selectquestion:: str-ex-digits
   :fromid: str-ex-digitsacq, str-ex-digitsansw
   :toggle: lock

.. selectquestion:: str-ex-name
   :fromid: str-ex-nameacq, str-ex-nameansw
   :toggle: lock

.. selectquestion:: str-ex-nameInput
   :fromid: str-ex-nameInputacq, str-ex-nameInputansw
   :toggle: lock

.. selectquestion:: str-ex-lower
   :fromid: str-ex-loweracq, str-ex-loweransw
   :toggle: lock

